@@ -1,5 +1,5 @@
 package Reply::Plugin::Prompt;
-$Reply::Plugin::Prompt::VERSION = '0.0.17.0';
+$Reply::Plugin::Prompt::VERSION = '0.0.18.0';
 use strict;
 use warnings;
 use Cwd qw(abs_path getcwd);
@@ -229,15 +229,16 @@ Reply::Plugin::Prompt - reply plugin for powerlevel10k style prompt
 
 =head1 VERSION
 
-version 0.0.17.0
+version 0.0.18.0
 
 =head1 DESCRIPTION
 
 L<Reply> plugin for L<powerlevel10k|https://github.com/romkatv/powerlevel10k>
 style prompt. It is an enhancement of L<Reply::Plugin::FancyPrompt>.
 
-Your perl deserves a beautiful REPL. See
-L<README.md|https://github.com/Freed-Wu/Reply-Plugin-Prompt> for screenshots.
+Your perl deserves a beautiful REPL.
+
+See L<README.md|https://github.com/Freed-Wu/Reply-Plugin-Prompt> for screenshots.
 
 Now this plugin supports L<wakatime|https://wakatime.com> which will record your
 time to use perl in L<Reply>. If you don't want it, please remove I<wakatime>
